"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.File = void 0;

var _compose = _interopRequireDefault(require("lodash/fp/compose"));

var _webinyValidation = require("webiny-validation");

var _name = require("@commodo/name");

var _hooks = require("@commodo/hooks");

var _fields = require("@commodo/fields");

const File = (0, _compose.default)((0, _hooks.withHooks)({
  async beforeCreate() {
    if (!this.src.startsWith("/") || this.src.startsWith("http")) {
      throw Error(`File "src" must be a relative path, starting with forward slash ("/").`);
    }

    if (await this.getModel("File").findOne({
      query: {
        src: this.src
      }
    })) {
      throw Error(`File "src" must be unique. `);
    }
  }

}), (0, _fields.withFields)({
  size: (0, _fields.number)({
    validation: _webinyValidation.validation.create("required")
  }),
  type: (0, _fields.string)({
    validation: _webinyValidation.validation.create("required,maxLength:50")
  }),
  src: (0, _fields.string)({
    validation: _webinyValidation.validation.create("required,maxLength:200")
  }),
  name: (0, _fields.string)({
    validation: _webinyValidation.validation.create("required,maxLength:100")
  }),
  tags: (0, _fields.onSet)(value => {
    if (value) {
      return value.map(item => item.toLowerCase());
    }

    return value;
  })((0, _fields.string)({
    list: true,
    validation: tags => {
      if (Array.isArray(tags)) {
        if (tags.length > 15) {
          throw Error("You cannot set more than 15 tags.");
        }

        for (let i = 0; i < tags.length; i++) {
          let tag = tags[i];

          if (typeof tag !== "string") {
            throw Error("Tag must be typeof string.");
          }

          if (tag.length > 50) {
            throw Error(`Tag ${tag} is more than 50 characters long.`);
          }
        }
      }
    }
  }))
}), (0, _name.withName)("File"))(function () {});
exports.File = File;
//# sourceMappingURL=File.model.js.map